@@ -65,7 +65,7 @@ class Freebox(IPlugin):
 	# ###   140826			while i <= int(rs['idx_sec']):
 #
 # 
-					for i in range (1, int(rs['idx_sec'])):
+					for i in range int(rs['idx_sec']):
 		#				if rs['idx'][i - rang] == '|':
 						rangs.append(rang)
 						log.msg(" rang  :  %s" % (rangs)
@@ -76,7 +76,7 @@ class Freebox(IPlugin):
 #[5, 7]
 					# search position '|' dans rs['idx']	
 					# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
-					for rx in range (1, int(rs['idx_sec'])):
+					for rx in range int(rs['idx_sec']):
 						log.msg(" rx  :  %s" % (rx)
 						log.msg("idx_sec  :  %s" % (int(rs['idx_sec'])))
 						log.msg("idx  :  %s" % (rs['idx']))
